==> clj-scw-client-0.1.1-20250627.120733-1.jar: monkey/scw/openapi.clj <==
(ns monkey.scw.openapi
  (:require [aleph.http :as http]
            [clj-yaml.core :as yaml]
            [clojure.java.io :as io]
            [clojure.walk :as walk]
            [manifold.deferred :as md]))

(defn- throw-on-error [{:keys [status] :as resp}]
  (when (>= status 400)
    (throw (ex-info "Got error response" resp)))
  resp)

(defn load-definition [url]
  (letfn [(parse [b]
            (with-open [r (io/reader b)]
              (yaml/parse-stream r)))]
    (md/chain
     (http/get url {:as :text})
     throw-on-error
     :body
     parse)))

(defn- parse-bool [{:keys [default] :as s}]
  (cond-> s
    (string? default) (update :default Boolean/parseBoolean)))

(defn- parse-int [{:keys [default] :as s}]
  (cond-> s
    (string? default) (update :default Integer/parseInt)))

(def patchers
  {"boolean" parse-bool
   "integer" parse-int})

(defn patch-schema
  "Some schema definitions provide a default value that does not match the type
   (e.g. string values instead of booleans or ints).  This functions patches those
   schemas by updating the default values."
  [s]
  (let [p (get patchers (:type s))]
    (cond-> s
      p (p))))

(defn fix-default-types
  "Applies patches to the input spec, to fix some errors that would make it fail
   schema coercion."
  [spec]
  (walk/prewalk
   (fn [f]
     (cond-> f
       (and (map? f) (contains? f :type) (contains? f :default))
       patch-schema))
   spec))

(defn remove-value-at
  "Patcher that removes the value at given path from the spec entirely"
  [path]
  (fn [spec]
    (update-in spec (drop-last path) dissoc (last path))))

==> clj-scw-client-0.1.1-20250627.141936-3.jar: monkey/scw/openapi.clj <==
(ns monkey.scw.openapi
  (:require [aleph.http :as http]
            [clj-yaml.core :as yaml]
            [clojure.java.io :as io]
            [clojure.walk :as walk]
            [manifold.deferred :as md]))

(defn- throw-on-error [{:keys [status] :as resp}]
  (when (>= status 400)
    (throw (ex-info "Got error response" resp)))
  resp)

(defn load-definition [url]
  (letfn [(parse [b]
            (with-open [r (io/reader b)]
              (yaml/parse-stream r :keywords false)))]
    (md/chain
     (http/get url {:as :text})
     throw-on-error
     :body
     parse)))

(defn- parse-bool [s]
  (cond-> s
    (string? (get s "default")) (update "default" Boolean/parseBoolean)))

(defn- parse-int [s]
  (cond-> s
    (string? (get s "default")) (update "default" Integer/parseInt)))

(def patchers
  {"boolean" parse-bool
   "integer" parse-int})

(defn patch-schema
  "Some schema definitions provide a default value that does not match the type
   (e.g. string values instead of booleans or ints).  This functions patches those
   schemas by updating the default values."
  [s]
  (let [p (get patchers (get s "type"))]
    (cond-> s
      p (p))))

(defn fix-default-types
  "Applies patches to the input spec, to fix some errors that would make it fail
   schema coercion."
  [spec]
  (walk/prewalk
   (fn [f]
     (cond-> f
       (and (map? f) (contains? f "type") (contains? f "default"))
       patch-schema))
   spec))

(defn remove-value-at
  "Patcher that removes the value at given path from the spec entirely"
  [path]
  (fn [spec]
    (update-in spec (drop-last path) dissoc (last path))))
